==> cms-db_v0.7.11.tar.gz: admin/locales/de/locale_firstrun.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['firstrun'] = array();

$locale['firstrun']['title_installation'] = 'Installation';
$locale['firstrun']['desc_installation'] = 'Das CMS wird jetzt konfiguriert. In der oberen rechten Ecke können Sie die Sprache ändern.';
$locale['firstrun']['link_installation'] = 'Installationsassistent starten';

$locale['firstrun']['title'] = 'Installationsassistent';
$locale['firstrun']['desc_whatsthis'] = 'Der Installationsassistent richtet cms -db ein.';
$locale['firstrun']['desc_clickbutton'] = 'Klicken Sie auf <i>%s</i>, um mit der Installation fortzufahren.';

$locale['firstrun']['title_step1'] = 'Installationsassistent - Schritt 1';
$locale['firstrun']['title_fileperms'] = 'Überprüfung der Dateiberechtigungen';
$locale['firstrun']['desc_fileperms'] = 'Bei allen Dateien muss die Zahl am rechten Rand grün hinterlegt sein. Falls dies bei einer Datei nicht der Fall ist, müssen Sie der Datei Schreibrechte geben (z.B. über ein FTP-Programm).';
$locale['firstrun']['desc_correct-fileperms'] = 'Sie müssen den Dateien die richtigen Rechte geben, um fortfahren zu können. (%s von %s müssen geändert werden.)';

$locale['firstrun']['title_step2'] = 'Installationsassistent - Schritt 2';
$locale['firstrun']['title_unzip'] = 'Entpacken der Basisdateien';
$locale['firstrun']['desc_unzip'] = 'Das Daten-Archiv wird jetzt entpackt:';
$locale['firstrun']['desc_unzipping'] = 'Entpacke <i>%s</i> nach <i>%s</i> ... %s';
$locale['firstrun']['desc_unzipped'] = 'Das Archiv wurde entpackt.';

$locale['firstrun']['title_step3'] = 'Installationsassistent - Schritt 3';
$locale['firstrun']['title_user'] = 'Zugangsdaten festlegen';
$locale['firstrun']['desc_user'] = 'Bitte geben Sie die gewünschten Zugangsdaten für den Hauptbenutzer an. Der Hauptbenutzer darf alle Einstellungen ändern!';

$locale['firstrun']['title_step4'] = 'Installationsassistent - Schritt 4';
$locale['firstrun']['title_finished'] = 'Abschließen der Installation';
$locale['firstrun']['desc_finished'] = 'Die Installation von cms -db wurde beendet. Sie können sich jetzt anmelden und mit dem Anpassen des Templates und den Einstellungen sowie mit dem Bearbeiten von Seiten beginnen.';
$locale['firstrun']['link_login'] = 'Anmelden';
?>

==> cms-db_v0.8.1.tar.gz: admin/locales/de/locale_firstrun.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['firstrun'] = array();

$locale['firstrun']['title_installation'] = 'Installation';
$locale['firstrun']['desc_installation'] = 'Das CMS wird jetzt eingerichtet. In der oberen rechten Ecke können Sie die Sprache ändern.';
$locale['firstrun']['link_installation'] = 'Installationsassistent starten';

$locale['firstrun']['title'] = 'Installationsassistent';
$locale['firstrun']['desc_whatsthis'] = 'Der Installationsassistent richtet cms -db ein.';
$locale['firstrun']['desc_clickbutton'] = 'Klicken Sie auf <i>%s</i>, um mit der Installation fortzufahren.';

$locale['firstrun']['title_step1'] = 'Installationsassistent - Schritt 1';
$locale['firstrun']['title_fileperms'] = 'Überprüfung der Dateiberechtigungen';
$locale['firstrun']['desc_fileperms'] = 'Bei allen Dateien muss die Zahl am rechten Rand grün hinterlegt sein. Falls dies bei einer Datei nicht der Fall ist, müssen Sie der Datei Schreibrechte geben (z.B. über ein FTP-Programm).';
$locale['firstrun']['desc_correct-fileperms'] = 'Sie müssen den Dateien die richtigen Rechte geben, um fortfahren zu können. (%s von %s müssen geändert werden.)';

$locale['firstrun']['title_step2'] = 'Installationsassistent - Schritt 2';
$locale['firstrun']['title_unzip'] = 'Entpacken der Basisdateien';
$locale['firstrun']['desc_unzip'] = 'Das Datenarchiv wird jetzt entpackt:';
$locale['firstrun']['desc_unzipping'] = 'Entpacke <i>%s</i> nach <i>%s</i> ... %s';
$locale['firstrun']['desc_unzipped'] = 'Das Archiv wurde entpackt.';

$locale['firstrun']['title_step3'] = 'Installationsassistent - Schritt 3';
$locale['firstrun']['title_user'] = 'Zugangsdaten festlegen';
$locale['firstrun']['desc_user'] = 'Bitte geben Sie die gewünschten Zugangsdaten für den Hauptbenutzer an. Der Hauptbenutzer darf alle Einstellungen ändern!';

$locale['firstrun']['title_step4'] = 'Installationsassistent - Schritt 4';
$locale['firstrun']['title_finished'] = 'Abschließen der Installation';
$locale['firstrun']['desc_finished'] = 'Die Installation von cms -db wurde beendet. Sie können sich jetzt anmelden und mit dem Anpassen des Templates und den Einstellungen sowie mit dem Bearbeiten von Seiten beginnen.';
$locale['firstrun']['link_login'] = 'Anmelden';
?>
